@@ -1,13 +1,15 @@
-import pandas as pd
+from typing import Union
+
 import dask.dataframe as dd
+import pandas as pd
 from dagster import InputDefinition
 from qdk.dagster_types import DataFrameType, SeriesType
-from qdk.training.base import TrainingComponent
-from typing import Union
+from qdk.training.base import BaseTrainer
+
 from sklearn.base import BaseEstimator
 
 
-class SklearnComponent(TrainingComponent):
+class SklearnTrainer(BaseTrainer):
     input_defs = [
         InputDefinition("X", DataFrameType),
         InputDefinition("y", SeriesType),
